@@ -809,7 +809,7 @@ class BackendBase(implements(BackendInterface)):
 
         # emit cmds to MOUNT WORKSPACE and export/set releated environment variables
         if not gen_for_windows:
-            # always mount WORKSPACE container
+            # on linux, always mount WORKSPACE container
             workspace = args["workspace"]
 
             if self.mounting_enabled:
@@ -823,7 +823,7 @@ class BackendBase(implements(BackendInterface)):
                     sudo_available=sudo_available, use_username=use_username, use_allow_other=use_allow_other, 
                     nonempty=nonempty, cleanup_needed=True)
 
-            # always mount JOBS container
+            # on linux, always mount JOBS container
             jobs_container = store_utils.get_jobs_container(workspace)
 
             if self.mounting_enabled:
@@ -841,10 +841,15 @@ class BackendBase(implements(BackendInterface)):
             store_path = "{}/jobs/{}/node-{}".format(jobs_mount_dir, job_id, self.node_index)
             self.append_export(cmds, "XT_NODE_DIR", store_path)
 
-            # XT_OUTPUT_DIR
-            run_path = store_utils.get_run_path(job_id, self.run_name) 
-            store_path = "{}/{}/output".format(workspace_mount_dir, run_path)
-            self.append_export(cmds, "XT_OUTPUT_DIR", store_path)
+        # on windows or linux, always define the output dir (even if it is not mounted)
+        # XT_OUTPUT_DIR
+        run_path = store_utils.get_run_path(job_id, self.run_name) 
+        store_path = "{}/{}/output".format(workspace_mount_dir, run_path)
+        self.append_export(cmds, "XT_OUTPUT_DIR", store_path)
+    
+        # create it so the user doesn't trip over missing dir
+        # surround dir with quotes so windows doesn't complain about forward slashes
+        self.append(cmds, 'mkdir "{}"'.format(store_path))
 
         # emit cmds to MOUNT or DOWNLOAD data
         if "data" in actions:
@@ -873,12 +878,20 @@ class BackendBase(implements(BackendInterface)):
         we cannot rely on blobfuse mapping, and we know we have xtlib installed.
         '''
 
+        # # debug (ensure azureml-logs is present on ITP runs)
+        # self.append_dir(cmds)
+        # self.append_dir(cmds, "logs/azureml")
+        # self.append(cmds, "cp -r logs  {}".format(constants.AFTER))
+
         self.append_title(cmds, "UPLOAD service and XT logs to job storage:")
 
         job_id = args["job_id"]
         workspace = args["workspace"]
 
-        store_path = "$jobs/{}/node-{}/after".format(job_id, self.node_index)
+        # workaround for "$jobs" not resolving correctly on compute node
+        #store_path = "$jobs/{}/node-{}/after".format(job_id, self.node_index)
+        jobs_container = store_utils.get_jobs_container(workspace)
+        store_path = "/{}/jobs/{}/node-{}/after".format(jobs_container, job_id, self.node_index)
 
         if self.gen_for_windows:
             # have backend add its needed cmds to copy the service logs
@@ -886,7 +899,7 @@ class BackendBase(implements(BackendInterface)):
 
             # upload both XT logs and service logs to job after dir
             # specify workspace since our config file isn't present on the compute node
-            self.append(cmds, "xt upload {} {} --feedback=0 --workspace={}".format(constants.AFTER, store_path, workspace))
+            self.append(cmds, "xt upload {} {} --feedback=0".format(constants.AFTER, store_path))
 
         else:
             # copy xt_logs to output node dir
