@@ -147,7 +147,7 @@ class BackendInterface(Interface):
         pass
 
     # API call
-    def cancel_runs_by_user(self, box_name):
+    def cancel_runs_by_user(self, ws_name, box_name):
         '''
         Args:
             box_name: the name of the box the runs ran on (pool service)
@@ -255,3 +255,20 @@ class BackendInterface(Interface):
             gathers and returns the list of current + queue entries.
         '''
         pass
+    
+    # API call
+    def add_service_log_copy_cmds(self, cmds, dest_dir, store_path, args):
+        '''
+        Args:
+            cmds - list of cmds for appending generated cmds to
+            dest_dir - the local node directory where logs should be copied
+            store_path - where the logs should be copied to the cloud (normally not needed)
+            args - dict of command arguments (usually run command)
+
+        Returns:
+            None
+
+        Description:
+            Generate cmds to copy services log files to the dest_dir.
+        '''
+        pass
\ No newline at end of file
