@@ -539,8 +539,8 @@ class Philly(BackendBase):
                 # update mongo db info for run with cluster and service_job_id
 
                 # add newly acquired info (service_run_id)
-                mongo.update_mongo_run_from_dict(workspace, run_name, 
-                    {"cluster": cluster, "vc": vc, "service_run_id": service_job_id})
+                rd = {"cluster": cluster, "vc": vc, "service_run_id": service_job_id}
+                mongo.update_run_info(workspace, run_name, rd, update_primary=True)
 
                 #fb.feedback("{}/{}".format(workspace, run_name), id="run_name", add_seperator=False)
                 fb.feedback("{}/{}".format(workspace, run_name))
