@@ -215,14 +215,14 @@ class PoolBackend(BackendBase):
         psm_client.restart_psm_if_needed()
         #print("psm created for box: " + box_addr)
 
-        service_set_name = self.config.get("service-set")
+        store_name = self.config.get("store")
         node_id = utils.node_id(box_index)
 
         cwd_dir = os.path.expanduser(constants.CWD_DIR)
         fn_src_zip = file_utils.path_join(cwd_dir, constants.CODE_ZIP_FN)
         workspace = args["workspace"]
 
-        fn_entry = psm_client.enqueue(service_set_name, workspace, job_id, run_name, box_index, fn_src_zip)
+        fn_entry = psm_client.enqueue(store_name, workspace, job_id, run_name, box_index, fn_src_zip)
 
         service_node_info = {"fn_entry": fn_entry, "box_addr": box_addr, "box_os": box_os, 
             "box_name": box_name, "job_id": job_id, "run_name": run_name}
