@@ -378,7 +378,7 @@ class CmdCore():
 
         mongo_creds, mongo_name = self.config.get_mongo_creds()
 
-        ss_info = self.config.get_service_set_info()
+        ss_info = self.config.get_store_info()
         storage_tracking = utils.safe_value(ss_info, "track-storage")
 
         if storage_tracking:
