@@ -10,10 +10,10 @@ here, check to see if you need to also change it in psm.py.
 '''
 
 #Sync the BUILD string changes with: setup.py, CHANGELOG.md
-BUILD = "version: 0.0.222, build: Sep-02-2020"
+BUILD = "version: 0.0.223, build: Sep-05-2020"
     
-INFO_CONTAINER = "00-store-info"
 INFO_CONTAINER_V1 = "xt-store-info"
+INFO_CONTAINER_V2 = "00-store-info"
 
 INFO_DIR = "__info__"
 STORAGE_FORMAT = "2"
