@@ -76,8 +76,9 @@ def get_command_dicts(prev_exper, curr_exper, browse_flag, browse_opt, timeout_o
 
 	    {"title": "download all source code, output, and logs for run2", "xt_cmd": "xt extract run2 {} {}".format(archives_dir, browse_opt)},
 
+        # TODO: replace imported runs with new ones; rerun cmd is failing due to trying to use out of date CONFIG file
 	    # RERUN (monitor_opt is harder to apply here)
-	    {"title": "rerun run2, with original source code and hyperparameter settings", "xt_cmd": "xt rerun run2"},
+	    #{"title": "rerun run2, with original source code and hyperparameter settings", "xt_cmd": "xt rerun run2"},
 
 	    # MOUNT data and DOWNLOAD model
 	    {"title": "run script, mounting data and downloading model for eval", 
