@@ -29,9 +29,11 @@ cmd_count = 0
 
 ARCHIVES_DIR = "..\\xt_demo_archives"
 
-def build_cmds(auto_mode, quick_test, nomonitor, nogui):
+def build_cmds(auto_mode, quick_test, nomonitor, nogui, philly=1, basic_mode=None):
     config = xt_config.get_merged_config()
-    mini_mode = not config.get("general", "advanced-mode")
+
+    if basic_mode is None:
+        basic_mode = not config.get("general", "advanced-mode")
 
     is_windows = (os.name == "nt")
     has_gui = pc_utils.has_gui() and not nogui
@@ -45,7 +47,7 @@ def build_cmds(auto_mode, quick_test, nomonitor, nogui):
     prev_exper = "exper18"
     curr_exper = "exper26"
 
-    if mini_mode:
+    if basic_mode:
         command_dicts = commands_basic.get_command_dicts(
             prev_exper,
             curr_exper,
@@ -71,6 +73,11 @@ def build_cmds(auto_mode, quick_test, nomonitor, nogui):
             lambda c_dict: not utils.safe_value(c_dict, "needs_gui", default=False),
             command_dicts))
 
+    if philly == 0:
+        command_dicts = filter(
+            lambda c_dict: not utils.safe_value(c_dict, "needs_philly", default=False),
+            command_dicts)
+
     list(map(
         lambda cmd_dict: add_cmd(cmd_dict["title"], cmd_dict["xt_cmd"]),
         command_dicts
@@ -85,24 +92,32 @@ def add_cmd(title=None, xt_cmd=None, silent=False):
     cmd = {"title": title, "xt_cmd": xt_cmd, "silent": silent}
     cmds.append(cmd)
 
-def wait_for_nav_key(auto_mode):
+def wait_for_nav_key(cmd_text, auto_mode):
+    print(" > " + cmd_text + " ", end="", flush=True)
+
     if auto_mode:
         response = "\r"
     else:
         # get KEYPRESS from user
         while True:
+    
             with KeyPressChecker() as kpc:
                 response = kpc.getch_wait()
-                #xtprint("got reponse=", response)
+                #print("getch: ord(response)={}".format(ord(response)))
 
-            # treat control-c as "q"
-            if response == b'\x03':
+                if not response or ord(response) == 0:
+                    continue
+
+            # treat control-c and ESCAPE as "q"
+            if ord(response) in [3, 27]:
                 response = "q"
 
             if response in ["\r", "\n", "s", "b", "q"]:
                 break
 
-            print("? ", end="", flush=True)
+            #print("? ", end="", flush=True)
+            print("(press ENTER to run, 'q' to quit, 's' for skip, or 'b' for back)")
+            print(" > " + cmd_text + " ", end="", flush=True)
 
     print()
     return response
@@ -170,9 +185,8 @@ def navigate(cmds, auto_mode, steps):
             #     cmd_text = cmd_text.replace("--open", "")
 
         print("xt demo {}/{}: {}".format(index+1, len(cmds), cmd["title"]))
-        print(" > " + cmd_text + " ", end="", flush=True)
 
-        response = wait_for_nav_key(auto_mode)
+        response = wait_for_nav_key(cmd_text, auto_mode)
         #print("response=", response, 'b"q"=', b"q", response == b"q")
 
         if response in ["\r", "\n"]:
@@ -221,9 +235,11 @@ def parse_args(arg_list=None):
     parser = argparse.ArgumentParser(description='XT Demo')
 
     parser.add_argument('--auto', action='store_true', default=False, help='runs the demo unattended')
-    parser.add_argument('--nomonitor', action='store_true', default=False, help='prevents monitoring of XT run commands')
     parser.add_argument('--nogui', action='store_true', default=False, help='prevents running of GUI commands')
-    parser.add_argument('--quick-test', action='store_true', default=False, help='specifies we are running as part of the quick-test')
+    parser.add_argument('--nomonitor', action='store_true', default=False, help='prevents monitoring of XT run commands')
+    parser.add_argument('--philly', default=1, type=int, help='should Philly tests be run')
+    parser.add_argument('--basic_mode', default=None, type=int, help='should Philly tests be run')
+    parser.add_argument('--quick_test', default=0, type=int, help='specifies we are running as part of the quick-test')
     parser.add_argument("steps", nargs="*", help="the steps to be run")
 
     if not arg_list:
@@ -268,11 +284,13 @@ def main(arg_list=None):
     nomonitor = args.nomonitor
     nogui = args.nogui
     quick_test = args.quick_test
+    philly = args.philly
+    basic_mode = args.basic_mode
 
-    build_cmds(auto_mode, quick_test, nomonitor, nogui)
+    build_cmds(auto_mode, quick_test, nomonitor, nogui, philly=philly, basic_mode=basic_mode)
 
     steps = parse_steps(args.steps)
-    response = ""
+    run_tests = True
 
     if not auto_mode:
         print()
@@ -283,7 +301,10 @@ def main(arg_list=None):
         print("hit any key to continue: ", end="", flush=True)
         response = wait_for_any_key(auto_mode)
 
-    if response != "q":
+        if response == "q" or ord(response) in [3, 27]:
+            run_tests = False
+    
+    if run_tests:
         navigate(cmds, auto_mode, steps)
 
     # clean-up
