@@ -129,11 +129,16 @@ class XTConfig():
             from xtlib import xt_vault 
 
             # create our vault manager
-            vault_url = self.get_vault_url()
+            vault_creds = self.get_vault_creds()
 
-            service_set_name = self.get("service-set")
+            if not "url" in vault_creds:
+                errors.config_error("URL not specified for '{}' in [external-services] section of XT config file".format(vault_name))
 
-            self.vault = xt_vault.XTVault(vault_url, service_set_name)
+            vault_url = vault_creds["url"]
+            secret_name = utils.safe_value(vault_creds, "secret-name", "xt-keys")
+            store_name = self.get("store")
+
+            self.vault = xt_vault.XTVault(vault_url, store_name, secret_name)
 
             authentication = self.get("general", "authentication")
             self.vault.init_creds(authentication)
@@ -273,10 +278,10 @@ class XTConfig():
 
     def get_storage_creds(self):
         # validate STORAGE service
-        ss_info = self.get_service_set_info()
+        ss_info = self.get_store_info()
         storage_name = utils.safe_value(ss_info, "storage")
         if not storage_name:
-            errors.config_error("'storage' property must be set in service-set '{}'".format(ss_info["name"]))
+            errors.config_error("'storage' property must be set in store '{}'".format(ss_info["name"]))
 
         # validate STORAGE_NAME credentials
         storage_creds = self.get("external-services", storage_name, suppress_warning=True)
@@ -289,10 +294,10 @@ class XTConfig():
 
     def get_mongo_creds(self):
         # validate MONGO service
-        ss_info = self.get_service_set_info()
+        ss_info = self.get_store_info()
         mongo_name = utils.safe_value(ss_info, "mongo")
         if not mongo_name:
-            errors.config_error("'mongo' property must be set in service-set '{}'".format(ss_info["name"]))
+            errors.config_error("'mongo' property must be set in store '{}'".format(ss_info["name"]))
 
         # validate MONGO credentials
         mongo_creds = self.get("external-services", mongo_name, suppress_warning=True)
@@ -302,9 +307,9 @@ class XTConfig():
         #self.expand_symbols_in_creds(mongo_creds, mongo_name)
         return mongo_creds, mongo_name
 
-    def get_vault_url(self):
+    def get_vault_creds(self):
         # validate VAULT service
-        ss_info = self.get_service_set_info()
+        ss_info = self.get_store_info()
         vault_name = utils.safe_value(ss_info, "vault")
         if not vault_name:
             # empty value name is acceptable for some service sets
@@ -315,11 +320,8 @@ class XTConfig():
         if not vault_creds:
             errors.config_error("'{}' must be specified in [external-services] section of XT config file".format(vault_name))
 
-        if not "url" in vault_creds:
-            errors.config_error("URL not specified for '{}' in [external-services] section of XT config file".format(vault_name))
-
-        url = vault_creds["url"]
-        return url
+        vault_creds["name"] = vault_name
+        return vault_creds
 
     def get_storage_type(self):
         return "azure-store"
@@ -439,19 +441,19 @@ class XTConfig():
 
         return target_str
 
-    def get_service_set_info(self, service_set_name=None):
-        if not service_set_name:
-            service_set_name = self.get("service-set", suppress_warning=True)
+    def get_store_info(self, store_name=None):
+        if not store_name:
+            store_name = self.get("store", suppress_warning=True)
             
-        if not service_set_name:
-            errors.config_error("XT config file is missing required property: service-set")
+        if not store_name:
+            errors.config_error("XT config file is missing required property: store")
         
-        service_set_info = self.get("service-sets", service_set_name, suppress_warning=True)
-        if not service_set_info:
-            errors.config_error("XT config file is missing definition for service-set: {}".format(service_set_name))
+        store_info = self.get("stores", store_name, suppress_warning=True)
+        if not store_info:
+            errors.config_error("XT config file is missing definition for store: {}".format(store_name))
 
-        service_set_info["name"] = service_set_name
-        return service_set_info
+        store_info["name"] = store_name
+        return store_info
 
 # flat functions
 
@@ -517,7 +519,7 @@ def _apply_basic_mode_rules(config):
 
         # single target
         # TODO: are we going to support "local" for basic mode?  
-        ss_info = config.get_service_set_info()
+        ss_info = config.get_store_info()
         ss_info["target"] = "batch"
 
 def get_merged_config(create_if_needed=True, local_overrides_path=None, suppress_warning=False):
