@@ -14,11 +14,10 @@ import numpy as np
 import yaml
 
 from xtlib import console
+from xtlib import search_helper
 from xtlib.hparams import hp_helper
 from xtlib.storage.store import Store
-
 from xtlib.helpers.xt_config import get_merged_config
-from xtlib.storage.store import Store
 
 plt = None     # JIT import to keep XT from always loading matplotlib (and font cache building)
 
@@ -326,6 +325,9 @@ class SearchHistory():
         self.best_runset_trophies = []
         self.xtstore = None
 
+        self.ws_name = workspace if workspace else args.workspace
+
+
     def init_xtstore(self):
         if self.xtstore is None:
             xt_config = get_merged_config(create_if_needed=False)
@@ -340,7 +342,11 @@ class SearchHistory():
             hp_config_path = self.DIR_PATH + self.args.hp_def_file
             if not exists(hp_config_path):
                 self.init_xtstore()
-                self.xtstore.download_file_from_job(self.args.job, 'hp-config-dir/' + self.args.hp_def_file, hp_config_path)
+
+                #job_path = constants.HP_CONFIG_DIR + self.args.hp_def_file
+                job_path = search_helper.get_hp_config_path(self.xtstore, self.ws_name, "job", self.args.job)
+
+                self.xtstore.download_file_from_job(self.ws_name, self.args.job, job_path, hp_config_path)
             self.define_hyperparameters_from_config_yaml(hp_config_path)
 
     def load_runs(self):
@@ -350,7 +356,7 @@ class SearchHistory():
 
         if not self.args.no_download:
             self.init_xtstore()
-            self.xtstore.download_file_from_job(self.args.job, runs_file_name, all_runs_file_path)
+            self.xtstore.download_file_from_job(self.ws_name, self.args.job, runs_file_name, all_runs_file_path)
 
         run_summaries = open(all_runs_file_path, 'r')
         self.num_incomplete_runs = 0
@@ -557,6 +563,7 @@ def parse_args(args_list=None):
     parser.add_argument('--metric', action='store', help='(For old jobs) Name of the metric maximized by HP tuning. Defaults to hpmax.', default='hpmax')
     parser.add_argument('--num_reports_per_run', action='store', help='(For old jobs) Expected number of metric reports in each run.', type=int, default=1)
     parser.add_argument('--hp_def_file', action='store', help='(For old jobs) Name of the file defining the HPs.', default='uploaded_hp_config.yaml')
+    parser.add_argument('--workspace', action='store', help='name of the workspace for the job', default='')
     return parser.parse_args(args_list)
 
 
