@@ -535,7 +535,7 @@ class HyperparameterExplorer(object):
             # read SWEEPS file
             if not store.does_job_file_exist(run_group_type, hp_config_cloud_path):
                 errors.store_error("missing job hp_config file (job={}, fn={})".format(run_group_type, hp_config_cloud_path))
-            store.download_file_from_job(run_group_type, hp_config_cloud_path, local_config_file_path)
+            store.download_file_from_job(ws_name, run_group_type, hp_config_cloud_path, local_config_file_path)
 
             # read ALLRUNS info aggregated in JOB
             allrun_records = store.get_all_runs(run_group_name, ws_name, run_group_type, batch_size=batch_size)
