@@ -113,7 +113,7 @@ class ImplCompute(ImplBase):
         '''
 
         if not target:
-            ss_info = self.config.get_service_set_info()
+            ss_info = self.config.get_store_info()
             target = utils.safe_value(ss_info, "target")
 
         if tensorboard:
@@ -887,12 +887,12 @@ class ImplCompute(ImplBase):
         storage = args["storage"]
 
         if not target:
-            ss_info = self.config.get_service_set_info()
+            ss_info = self.config.get_store_info()
             target = utils.safe_value(ss_info, "target")
             args["target"] = target
 
         if not storage:
-            ss_info = self.config.get_service_set_info()
+            ss_info = self.config.get_store_info()
             storage = utils.safe_value(ss_info, "storage")
             args["storage"] = storage
 
