@@ -12,7 +12,7 @@ import itertools
 from .console import console
 from .cmd_core import CmdCore
 from .impl_base import ImplBase
-from .qfe import command, argument, option, flag, root, example, command_help, kwgroup_help
+from .qfe import command, argument, option, flag, root, example, command_help, kwgroup_help, keyword_arg
 
 from xtlib import qfe
 from xtlib import utils
@@ -33,11 +33,11 @@ class ImplHelp(ImplBase):
         super(ImplHelp, self).__init__()
         self.core = CmdCore(config, None, None)
         self.config = config
-        self.mini_mode = False
+        self.basic_mode = False
         self.name = "xt"
 
-    def set_mini_mode(self, value):
-        self.mini_mode = value
+    def set_basic_mode(self, value):
+        self.basic_mode = value
         self.name = "xt"  
 
     def print_name_help_aligned(self, items, prefix="", separator=" ", name_field="name", help_prefix="", include_type=False, grouping_enabled=True):
@@ -124,7 +124,7 @@ class ImplHelp(ImplBase):
         console.print("XT")
         console.print("  - Command line app for managing and scaling ML experiments")
 
-        adv = "[advanced mode], " if not self.mini_mode else ""
+        adv = "[advanced mode], " if not self.basic_mode else ""
 
         console.print("  - " + adv + constants.BUILD)
         console.print("  - Copyright (c) 2020, Microsoft Corporation")
@@ -157,7 +157,7 @@ class ImplHelp(ImplBase):
     def help_docs(self, browse=False):
         url = "https://xtdocs.z22.web.core.windows.net/"
 
-        if self.mini_mode:
+        if self.basic_mode:
             url = "https://txtdocs.z22.web.core.windows.net/"
 
         if browse:
@@ -212,13 +212,13 @@ class ImplHelp(ImplBase):
     def command_summary(self):
 
         console.print()
-        adv = "[advanced mode], " if not self.mini_mode else ""
+        adv = "[advanced mode], " if not self.basic_mode else ""
         console.print("{} ({}{})".format(self.name.upper(), adv, constants.BUILD))
         
         console.print("Usage: {} [FLAGS] COMMAND [ARGS]...".format(self.name))
         console.print()
         
-        if self.mini_mode:
+        if self.basic_mode:
             console.print("  XT is used to manage and scale ML experiments.   Most command ")
             console.print("  and option keywords can be abbreviated down to 4 letters.")
         else:
@@ -239,7 +239,7 @@ class ImplHelp(ImplBase):
 
         self.assign_group_name(cmds)
 
-        if self.mini_mode:
+        if self.basic_mode:
             cmds = list(cmds)
             console.print("Commands:")
             cmds.sort(key=lambda cmd: cmd["name"])
@@ -402,7 +402,7 @@ class ImplHelp(ImplBase):
         # print usage info
         console.print(usage)
 
-        if show_all and not self.mini_mode:
+        if show_all and not self.basic_mode:
             # print command help    
             doc_string = self.get_formatted_doc_str(cmd_info)
 
@@ -412,6 +412,13 @@ class ImplHelp(ImplBase):
             console.print(help_text)
 
         if syntax_only:        
+            # show keywords for a keyword_arg, if any
+            if args:
+                arg = args[-1]
+                if "keywords" in arg:
+                    keywords = arg["keywords"]
+                    console.print("  {}: {}".format(arg["name"], or_join(keywords)))
+
             # show a quck list of options
             console.print("  OPTIONS: ", end="")
             for opt in options:
@@ -436,7 +443,7 @@ class ImplHelp(ImplBase):
                 console.print("  > {}".format(example["text"]))
                 console.print()
 
-                if self.mini_mode:
+                if self.basic_mode:
                     # only show first example for mini mode
                     break
 
@@ -447,7 +454,7 @@ class ImplHelp(ImplBase):
                 console.print("  => {}".format(faq["answer"]))
                 console.print()
 
-                if self.mini_mode:
+                if self.basic_mode:
                     # only show first FAQ for mini mode
                     break
 
@@ -611,3 +618,9 @@ class ImplHelp(ImplBase):
             count += 1
 
         console.print("{} files generated to: {}".format(count, dest_dir))
+
+# flat function
+def or_join(parts):
+    text = ", ".join(parts[:-1])
+    text += ", or " + parts[-1]
+    return text
\ No newline at end of file
