@@ -22,7 +22,9 @@ from xtlib import constants
 from xtlib import file_utils
 from xtlib import job_helper
 from xtlib import run_helper
+from xtlib import store_utils
 from xtlib import plot_builder
+from xtlib import search_helper
 from xtlib import process_utils
 from xtlib import box_information
 
@@ -120,7 +122,9 @@ class ImplStorage(ImplBase):
         names = self.store.get_workspace_names()
         #console.print("names=", names)
         fmt_workspace = utils.format_store(self.store.store_type)
-        console.print("\nXT workspaces:")
+        store_name = self.config.get("store")
+
+        console.print("workspaces on {}:".format(store_name))
         
         # console.print HEADERS
         if show_counts:
@@ -219,8 +223,9 @@ class ImplStorage(ImplBase):
     @example(task="list the experiments starting with the name 'george' in the 'curious' workspace", text="xt list exper george* --work=curious")
     @command(kwgroup="list", kwhelp="displays the specified storage items", help="list experiments defined in the current workspace")
     def list_experiments(self, wildcard, workspace, detail):
-        ws_name = workspace if workspace else workspace
-        console.print("Experiments for workspace: {}".format(ws_name))
+        ws_name = workspace 
+        store_name = self.config.get("store")
+        console.print("experiments on {}/{}:".format(store_name, workspace))
 
         # if self.is_aml_ws(ws_name):
         #     names = self.azure_ml.get_experiments(ws_name)
@@ -342,14 +347,14 @@ class ImplStorage(ImplBase):
 
     #---- IMPORT WORKSPACE command ----
     @argument(name="input-file", help="the name of the archive file (.zip) to import the workspace from")
-    @argument(name="new-workspace", required=False, help="the new name for the imported workspace")
+    @option(name="workspace", type=str, help="the new name for the imported workspace")
     @option(name="job-prefix", default="imp", help="the prefix to use for imported jobs (version 1 format)")
     @flag(name="overwrite", help="when True, an existing workspace of the same name will be overwritten")
-    @example(task="import workspace from workspace.zip as new_ws5", text="xt import workspace workspace.zip new_ws5")
+    @example(task="import workspace from workspace.zip as new_ws5", text="xt import workspace workspace.zip --work=new_ws5")
     @command(help="imports a workspace from a workspace archive file")
-    def import_workspace(self, input_file, new_workspace, job_prefix, overwrite):
+    def import_workspace(self, input_file, workspace, job_prefix, overwrite):
 
-        self.impl_storage_api.import_workspace(input_file, new_workspace, job_prefix, overwrite, show_output=True)
+        self.impl_storage_api.import_workspace(input_file, workspace, job_prefix, overwrite, show_output=True)
 
     #---- VIEW RUN command ----
     @argument(name="run-name", help="the name of the run")
@@ -399,14 +404,16 @@ class ImplStorage(ImplBase):
     @command(kwgroup="view", help="view the set of logged metrics for specified run")
     def view_metrics(self, runs, workspace, steps, merge, metrics, hparams, export):
 
-        args = {"run_list": runs, "workspace": workspace, "all": True, "sort_col": "name", 
-            "max_runs": None, "columns": ["run", "hparams.*", "metrics.*"]}
+        pure_run_list, ws_name = run_helper.expand_run_list(self.store, self.store.mongo, workspace, runs)
+        if not pure_run_list:
+            errors.general_error("no matching runs found")
 
-        # actual store col names (vs. user-level names) used here
-        col_dict = {"run_name": 1, "node_index": 1, "job_id": 1, "exper_name": 1, "ws": 1, "hparams": 1, "log_records": 1}
+        fd = {"ws_name": ws_name, "run_name": {"$in": pure_run_list}}
+        fields = {"_id": 1, "run_name": 1, "node_index": 1, "job_id": 1, "exper_name": 1, "ws": 1, "hparams": 1, "log_records": 1}
 
-        run_log_records, using_default_last, user_to_actual, available, builder, last, std_cols_desc = \
-            run_helper.get_filtered_sorted_limit_runs(self.store, self.config, False, col_dict=col_dict, args=args)
+        run_log_records = self.store.mongo.get_info_for_runs(ws_name, fd, fields, include_log_records=True)
+
+        store_utils.simplify_records_id(run_log_records)
 
         for rr in run_log_records:
             console.print("\n{}:".format(rr["_id"]), end="")
@@ -537,7 +544,7 @@ class ImplStorage(ImplBase):
 
         run_log_records, using_default_last, user_to_actual, available, builder, last, std_cols_desc = \
             run_helper.get_filtered_sorted_limit_runs(self.store, self.config, False, col_dict=col_dict, 
-            preserve_order=True, args=args)
+            preserve_order=True, col_names_are_external=False, flatten_records=False, args=args)
 
         # metric string will later contain calculated expressions
         if not col_list:
@@ -686,28 +693,6 @@ class ImplStorage(ImplBase):
         else:
             console.print("XT cache was not active")
 
-
-    def get_hp_config_path(self, aggregate_dest, dest_name, hp_config_dir, last_chance=False):
-        if aggregate_dest == "job":
-            _, filenames = self.store.get_job_filenames(dest_name, hp_config_dir)
-            if not filenames and last_chance:
-                errors.store_error("Missing hp-config file for job={}".format(dest_name))
-        else:
-            _, filenames = self.store.get_experiment_filenames(workspace, dest_name, hp_config_dir)
-            if not filenames and last_chance:
-                errors.store_error("Missing hp-config file for experiment={}".format(dest_name))
-
-        hp_config_path = None
-
-        if filenames:
-            for f in filenames:
-                if f.endswith('.yaml'):
-                    filename = f
-                    hp_config_path = hp_config_dir + "/" + filename
-                    break
-
-        return hp_config_path
-
     # ---- PLOT SUMMARY command ----
     @argument(name="aggregate-name", help="the name of the job or experiment where run have been aggregated (hyperparameter search)")
     @option(name="workspace", default="$general.workspace", help="the workspace that the experiment resides in")
@@ -720,10 +705,8 @@ class ImplStorage(ImplBase):
         dest_name = aggregate_name
         aggregate_dest = "job" if job_helper.is_job_id(dest_name) else "experiment"
 
-        hp_config_path = self.get_hp_config_path(aggregate_dest, aggregate_name, constants.HP_CONFIG_DIR)
-        if not hp_config_path:
-            # try old config dir name
-            hp_config_path = self.get_hp_config_path(aggregate_dest, aggregate_name, constants.OLD_HP_CONFIG_DIR, last_chance=True)
+        hp_config_path = search_helper.get_hp_config_path(self.store, workspace, 
+            aggregate_dest, aggregate_name)
 
         search_history = SearchHistory(agg_name=aggregate_name, workspace=workspace, timeout=timeout, primary_metric=primary_metric, 
             hp_config_file_name=hp_config_path)
@@ -756,10 +739,7 @@ class ImplStorage(ImplBase):
         dest_name = aggregate_name
         aggregate_dest = "job" if job_helper.is_job_id(dest_name) else "experiment"
 
-        hp_config_path = self.get_hp_config_path(aggregate_dest, aggregate_name, constants.HP_CONFIG_DIR)
-        if not hp_config_path:
-            # try old config dir name
-            hp_config_path = self.get_hp_config_path(aggregate_dest, aggregate_name, constants.OLD_HP_CONFIG_DIR, last_chance=True)
+        hp_config_path = search_helper.get_hp_config_path(self.store, workspace, aggregate_dest, aggregate_name)
 
         #console.print("found hp-hp_config_path file: ", hp_config_path)
 
@@ -825,7 +805,10 @@ class ImplStorage(ImplBase):
     @command(kwgroup="view", help="display information about the current or specified workspace")
     def view_workspace(self, workspace):
         # for now, its just an echo of your CURRENT (or specified) workspace name
-        console.print("workspace: {}".format(workspace))
+        store_name = self.config.get("store")
+
+        console.print("  workspace: {}".format(workspace))
+        console.print("  store: {}".format(store_name))
 
     #---- VIEW PORTAL command ----
     @argument(name="target-name", help="the name of the target whose portal is to be opened")
@@ -880,30 +863,29 @@ class ImplStorage(ImplBase):
         # for now, its just an echo of your CURRENT (or specified) workspace name
         console.print("experiment: {}".format(experiment))
 
-    #---- VIEW SERVICE SET command ----
-    @argument(name="name", default="$service-set", required=False, help="the name of the service set to use")
-    @example("xt view service-set dilbert", task="show information about the specified service set")
-    @command(kwgroup="view", help="display information about the active or specified service set")
-    def view_service_set(self, name):
-        # for now, its just an echo of your CURRENT (or specified) team name
-        ss_info = self.config.get_service_set_info(name)
+    #---- VIEW STORE command ----
+    @argument(name="name", default="$store", required=False, help="the name of the store to view")
+    @example("xt view store dilbert", task="show information about the specified store")
+    @command(kwgroup="view", help="display information about the current or specified store")
+    def view_store(self, name):
+        # for now, its just an echo of your CURRENT (or specified) store
+        ss_info = self.config.get_store_info(name)
 
         ss_info = dict(ss_info)    # make copy we can change
         name = ss_info["name"]
         del ss_info["name"]
 
-        console.print("service set {}: {}".format(name, ss_info))
+        console.print("store {}: {}".format(name, ss_info))
 
-    #---- LIST SERVICE SETS command ----
-    @example("xt list service sets", task="show the service sets defined in the xt config file")
-    @command(kwgroup="list", help="show the service sets defined in the xt config file")
-    def list_service_sets(self):
-        # for now, its just an echo of your CURRENT (or specified) team name
-        ss_infos = self.config.get("service-sets")
+    #---- LIST STORES command ----
+    @example("xt list stores", task="show the stores defined in the xt config file")
+    @command(kwgroup="list", help="show the stores defined in the xt config file")
+    def list_stores(self):
+        stores = self.config.get("stores")
 
-        console.print("service sets")
-        for name, ss_info in ss_infos.items():
-            console.print("  {}: {}".format(name, ss_info))
+        console.print("stores:")
+        for name, store in stores.items():
+            console.print("  {}: {}".format(name, store))
 
     #---- LIST RUNS command ----
     @argument(name="run-list", type="str_list", help="a comma separated list of: run names, name ranges, or wildcard patterns", required=False)
@@ -1524,7 +1506,7 @@ class ImplStorage(ImplBase):
           
 
     #---- VIEW TENSORBOARD command ----
-    @argument(name="run-list", type="str_list", help="a comma separated list of: run names, name ranges, or wildcard patterns", required=False)
+    @argument(name="run-list", type="str_list", required=False, help="a comma separated list of: run names, name ranges, or wildcard patterns")
 
     @option(name="experiment", help="the experiment that the path is relative to")
     @option(name="interval", type=int, default=10, help="specifies interval between polling for changes in the run's 'output' storage")
@@ -1541,7 +1523,7 @@ class ImplStorage(ImplBase):
         '''
         # extract columns from template
         columns = []
-        us_columns = []
+        us_columns = []     # modified version of col names for use with python format() calls
         templ = template
 
         while "{" in templ:
@@ -1562,6 +1544,9 @@ class ImplStorage(ImplBase):
                 us_columns.append(col)
             templ = templ[index2+1:]
 
+        if not "job" in columns:
+            columns.append("job")
+
         args = {"experiment": experiment, "job": job, "run_list": run_list, "workspace": workspace, "columns": columns}
 
         # don't default to --last=10
@@ -1601,6 +1586,9 @@ class ImplStorage(ImplBase):
 
             run_records.append(rr)
 
+        if not run_records:
+            errors.general_error("no matching run(s) found")
+
         cwd = file_utils.fix_slashes(file_utils.make_tmp_dir("xt_tb_reader_", False), True)
 
         spd = self.store.get_props_dict()
@@ -1684,7 +1672,7 @@ class ImplStorage(ImplBase):
         if self.is_storage_tracker_running():
             errors.general_error("storage tracker is already running")
 
-        ss_info = self.config.get_service_set_info(None)
+        ss_info = self.config.get_store_info(None)
         track_storage = utils.safe_value(ss_info, "track-storage")
         if not track_storage:
             errors.general_error("service set 'track-storage' property must be set to 'true'")
