@@ -75,9 +75,6 @@ class ImplStorageApi():
         if len(workspaces) > 1:
             errors.combo_error("import of archive files with multiple workspaces not yet supported")
 
-        if not new_workspace:
-            new_workspace = workspaces[0]
-
         archive_version = contents["archive_version"]
         if not archive_version in ["1"]:
             errors.general_error("unrecognized archive format: {}".format(archive_version))
@@ -184,26 +181,9 @@ class ImplStorageApi():
     def import_run_mongo_document(self, archive_version, mongo_run_fn, workspace, new_workspace, prev_job_id, new_job_id, run_name, next_child_num):
         text = file_utils.read_text_file(mongo_run_fn)
         run = json.loads(text)
-        
+
         job_num = job_helper.get_job_number(new_job_id)
 
-        # if archive_version == '1':
-        #     if utils.safe_value(run, "is_child"):
-        #         # CHILD run
-        #         new_run_name = "run{}.{}".format(job_num, next_child_num)
-        #         next_child_num += 1
-
-        #     elif utils.safe_value(run, "is_parent"):
-        #         # PARENT run
-        #         node_index = utils.safe_value(run, "node_index", 0)
-        #         new_run_name = "run{}_{}".format(job_num, node_index)
-
-        #     else:
-        #         # FLAT RUN
-        #         new_run_name = "run{}".format(job_num)
-        # else:
-        #     new_run_name = run_name
-
         # we can preserve the run_name for both version 1 and version 2
         new_run_name = run_name
 
@@ -216,13 +196,15 @@ class ImplStorageApi():
                 del run["ws_name"]
         else:
             run["ws_name"] = new_workspace
+            if "ws" in run:
+                del run["ws"]
 
         if run_name != new_run_name:
             run["run_name"] = new_run_name
             run["run_number"] = run_helper.get_run_number(new_run_name)
 
         # add to mongo
-        self.store.mongo.update_run_info(new_workspace, new_run_name, run)
+        self.store.mongo.create_mongo_run(run)
 
         end_id = utils.safe_value(run, "end_id")
 
@@ -299,7 +281,8 @@ class ImplStorageApi():
             job_id = jr["job"]
             job_ws = jr["workspace"] 
 
-            mongo_runs = self.store.mongo.get_info_for_runs(job_ws, {"job_id": job_id}, None)
+            mongo_runs = self.store.mongo.get_info_for_runs(job_ws, {"job_id": job_id}, None, 
+                include_log_records=True)
             run_names = [mr["run_name"] for mr in mongo_runs]
 
             if show_output:
@@ -336,7 +319,7 @@ class ImplStorageApi():
 
                 # copy STORAGE RUN blobs
                 temp_store_path = os.path.join(temp_dir, "storage/workspaces/{}/runs/{}".format(job_ws, run_name))
-                self.export_run_storage_blobs(job_ws, run_name, temp_store_path)
+                self.export_run_storage_blobs(job_ws, job_id, run_name, temp_store_path)
 
         # add contents
         text = json.dumps(contents, indent=4)
@@ -368,12 +351,12 @@ class ImplStorageApi():
         self.download("**", temp_store_path, share=None, workspace=first_ws, experiment=None, job=job_id, 
             run=None, feedback=False, snapshot=True, show_output=False)
 
-    def export_run_storage_blobs(self, workspace, run_id, temp_store_path):
+    def export_run_storage_blobs(self, workspace, job_id, run_id, temp_store_path):
         # copy each storage file
         file_utils.ensure_dir_exists(temp_store_path)
 
         #fs = self.store.job_files(job_id, use_blobs=True)
-        self.download("**", temp_store_path, share=None, workspace=workspace, experiment=None, job=None, 
+        self.download("**", temp_store_path, share=None, workspace=workspace, experiment=None, job=job_id, 
             run=run_id, feedback=False, snapshot=True, show_output=False)
 
     # COMMAND
@@ -574,7 +557,7 @@ class ImplStorageApi():
             ws_name = store_utils.make_share_name(share)
             fs = self.store.root_files(ws_name, use_blobs=use_blobs)
         elif run_name:
-            fs = self.store.run_files(ws_name, run_name, use_blobs=use_blobs)
+            fs = self.store.run_files(ws_name, run_name, use_blobs=use_blobs, job_id=job_name)
         elif job_name:
             fs = self.store.job_files(ws_name, job_name, use_blobs=use_blobs)
         elif exper_name:
