@@ -80,6 +80,7 @@ class ImplUtilities(ImplBase):
     #---- XT ROOT FLAGS/OPTIONS ----
     @flag("help", help="Shows an overview of XT command syntax")
     @option("console", type=int, values=["none", "normal", "diagnostics", "detail"], default="$internal.console", help="sets the level of console output")
+    @option("store", type=str, default="$store", help="selects the store to be used from the stores list")
     @flag("stack-trace", default="$internal.stack-trace", help="Show stack trace when an exception is raised")
     @flag("quick-start", default="$general.quick-start", help="When true, XT startup time is reduced (experimental)")
     @flag("new", help="specifies that the current XT command should be run in a new console window")
@@ -94,6 +95,9 @@ class ImplUtilities(ImplBase):
         elif name == "console":
             console.set_level(value)
 
+        elif name == "store" and value:
+            self.config.data["store"] = value
+
         elif name == "stack-trace":
             utils.show_stack_trace = value
 
@@ -293,15 +297,15 @@ class ImplUtilities(ImplBase):
                 pass
 
     #---- GROK command ----
-    @option(name="service-set", default="$service-set", help="the service-set (aka team) to navigate to on the XT Grok website")
+    @option(name="store", default="$store", help="the store (aka team) to navigate to on the XT Grok website")
     @flag(name="browse", default=False, help="open the XT Grok URL in the browser")
     @example(task="open XT Grok in the browser, for the 'dilbert' team", text="xt browse --team=dilbert")
     @command(help="display or browse the XT Grok website")
-    def grok(self, service_set, browse):
+    def grok(self, store, browse):
 
         url = "https://grok.azurewebsites.net"
         if team:
-            url += "/#/teams/" + service_set
+            url += "/#/teams/" + store
 
         browse = browse and pc_utils.has_gui()
         
@@ -591,7 +595,7 @@ class ImplUtilities(ImplBase):
     def docker_login(self, target, docker):
 
         if not target:
-            ss_info = self.get_service_set_info()
+            ss_info = self.get_store_info()
             target = utils.safe_value(ss_info, "target")
 
         reg_creds = self.get_registry_creds(target, docker)
@@ -616,7 +620,7 @@ class ImplUtilities(ImplBase):
     def docker_logout(self, target, docker):
 
         if not target:
-            ss_info = self.get_service_set_info()
+            ss_info = self.get_store_info()
             target = utils.safe_value(ss_info, "target")
 
         reg_creds = self.get_registry_creds(target, docker)
