@@ -14,6 +14,7 @@ from xtlib import qfe
 from xtlib import utils
 from xtlib import errors
 from xtlib import file_utils
+from xtlib import store_utils
 
 def is_job_id(name):
     # compatible with version 1 (prefix-jobNNNN) and version 2 (jobNNNN)
@@ -84,12 +85,13 @@ def build_filter_part(fd, args, arg_name, store_name):
         else:
             fd[store_name] = value
 
-def build_job_filter_dict(job_list, user_to_actual, builder, workspace, args):
+def build_job_filter_dict(ws_name, job_list, user_to_actual, builder, workspace, args):
     fd = {}
     option_filters = ["experiment", "target", "service_type", "username", "status"]   # "application"
 
     if job_list:
         # filter by specified job names
+        job_list = [store_utils.make_id(ws_name, job) for job in job_list]
         fd["_id"] = {"$in": job_list}
 
     # filter by workspace
@@ -202,7 +204,7 @@ def get_list_jobs_records(store, config, args):
     job_list, actual_ws = expand_job_list(store, mongo, workspace, job_list)
 
     # build a filter dict for all specified filters
-    filter_dict = build_job_filter_dict(job_list, user_to_actual, builder, workspace, args)
+    filter_dict = build_job_filter_dict(workspace, job_list, user_to_actual, builder, workspace, args)
 
     # get the mongo records for the matching JOBS
     #console.print("gathering job data...", flush=True)
@@ -226,6 +228,10 @@ def list_jobs(store, config, args):
         avail_list = list(user_to_actual.keys())
         lines, row_count, was_exported = builder.build_report(records, report_type="job-reports", args=args)
 
+        store_name = config.get("store")
+        workspace = args["workspace"]
+        console.print("jobs on {}/{}:".format(store_name, workspace))
+
         if was_exported:
             console.print("")
 
