@@ -132,7 +132,7 @@ class PlotBuilder():
             metric_sets = run_helper.build_metrics_sets(log_records, timebase=self.timebase)
             if not metric_sets:
                 no_metrics.append(run)
-                continue    # SKIP this run
+                #continue    # SKIP this run
 
             if self.max_runs and len(pp_run_names) >= self.max_runs:
                 used_max = True
@@ -141,9 +141,9 @@ class PlotBuilder():
             if self.x_col:
                 # ensure x_col is in this run
                 if not self.is_col_in_sets(metric_sets, self.x_col):
-                    console.print("skipping: {} (missing metric: {})".format(run, self.x_col))
+                    console.print("warning: {} (missing metric: {})".format(run, self.x_col))
                     missing_col_runs += 1
-                    continue    # SKIP this run
+                    #continue    # SKIP this run
             else:
                 #if not "x" in explicit_options:
                 self.x_col = self.get_actual_x_column(metric_sets, self.x_col, self.col_names)
@@ -154,13 +154,13 @@ class PlotBuilder():
 
                 for col in self.col_names:
                     if not self.is_col_in_sets(metric_sets, col):
-                        console.print("skipping: {} (missing metric: {})".format(run, col))
+                        console.print("warning: {} (missing metric: {})".format(run, col))
                         found_all = False
                         break
 
                 if not found_all:
                     missing_col_runs += 1
-                    continue    # SKIP this run
+                    #continue    # SKIP this run
             else:
                 # not specified by user, so build defaults
                 self.col_names = self.get_default_y_columns(metric_sets, self.x_col)
@@ -174,7 +174,8 @@ class PlotBuilder():
                 
                 # ensure this df has our x_col 
                 if self.x_col and not self.x_col in cols:
-                    continue
+                    #continue
+                    pass
 
                 # ensure this df has at least 1 y_col
                 found_y = False
@@ -184,7 +185,8 @@ class PlotBuilder():
                         break
 
                 if not found_y:
-                    continue
+                    #continue
+                    pass
 
                 # add run_name column
                 df["run"] = [run] * df.shape[0]
@@ -203,7 +205,7 @@ class PlotBuilder():
             pp_run_names.append(run)
 
         if no_metrics:
-            console.print("\nnote: following runs were skipped (currently have no logged metrics): \n    {}\n".format(", ".join(no_metrics)))
+            console.print("\nnote: following runs currently have no logged metrics: \n    {}\n".format(", ".join(no_metrics)))
 
         if used_max:
             console.print("plotting first {} runs (use --max-runs to override)".format(self.max_runs))
@@ -639,69 +641,7 @@ class PlotBuilder():
         self.plot_inner(ax, group_name, col, self.x_col, x_label, line_index, plot_index, x_values=x, y_values=y, 
             color=color, alpha=self.alpha, use_y_label=True, err_values=err)
 
-    def plot_inner(self, ax, group_name, col, x_col, x_label, line_index, plot_index, x_values, y_values, 
-        color, alpha, use_y_label, y2_values=None, err_values=None):
-
-        import seaborn as sns
-        from matplotlib.ticker import MaxNLocator
-
-        if x_values is None:        
-            x_values = range(len(y_values))
-        else:
-            ax.set_xlabel(x_label)
-
-        console.detail("x_values=", x_values)
-        console.detail("y_values=", y_values)
-        console.detail("y2_values=", y2_values)
-
-        num_y_ticks = 10
-        ax.get_yaxis().set_major_locator(MaxNLocator(num_y_ticks))
-        #color = self.colors[line_index % len(self.colors)]
-
-        if use_y_label:
-            line_title = self.legend_titles[line_index % len(self.legend_titles)]
-            line_title = self.fixup_text(line_title, group_name, col)
-        else:
-            line_title = None
-
-        cap_size = 5
-        is_range_plot = bool(y2_values is not None)
-
-        # our default attributes
-        kwargs = {"label": line_title, "color": color, "alpha": alpha, "linewidth": self.line_size}
-        
-        if not is_range_plot:
-            kwargs["capsize"] = cap_size
-
-        # let user override
-        if self.plot_args and not is_range_plot:
-
-            for name, value in self.plot_args.items():
-                value = utils.make_numeric_if_possible(value)
-                kwargs[name] = value
-
-        #cmap = self.get_seaborn_color_map("muted")
-        if self.plot_type == "line":
-
-            if is_range_plot:
-
-                # RANGE plot
-                ax.fill_between(x_values, y_values, y2_values, **kwargs)
-
-            elif x_values is not None:
-
-                # X/Y LINE plot
-                 trace = ax.errorbar(x_values, y_values, yerr=err_values, **kwargs)  
-            else:
-
-                # LINE plot
-                ax.errorbar(y_values, '-', label=line_title, yerr=err_values, **kwargs)
-
-        else:
-            # for now, we can get lots of milage out of line plot (errorbars, scatter, scatter+line)
-            # so keep things simple and just support 1 type well 
-            errors.syntax_error("unknown plot type={}".format(self.plot_type))
-
+    def add_plot_legend_and_title(self, ax, plot_index, line_index, group_name, col, use_y_label):
         if self.plot_titles:
             plot_title = self.plot_titles[plot_index % len(self.plot_titles)]
             plot_title = self.fixup_text(plot_title, group_name, col)
@@ -709,11 +649,78 @@ class PlotBuilder():
             ax.set_title(plot_title)
 
         if self.show_legend:
-            ax.legend()
-
             if self.legend_args:
                 # pass legend args to legend object
                 ax.legend(**self.legend_args)
+            else:
+                ax.legend()
+        
+    def plot_inner(self, ax, group_name, col, x_col, x_label, line_index, plot_index, x_values, y_values, 
+        color, alpha, use_y_label, y2_values=None, err_values=None):
+
+        import seaborn as sns
+        from matplotlib.ticker import MaxNLocator
+
+        if y_values is not None and len(y_values):
+            if x_values is None:        
+                x_values = range(len(y_values))
+            else:
+                ax.set_xlabel(x_label)
+
+            if use_y_label:
+                line_title = self.legend_titles[line_index % len(self.legend_titles)]
+                line_title = self.fixup_text(line_title, group_name, col)
+            else:
+                line_title = None
+                
+            console.detail("x_values=", x_values)
+            console.detail("y_values=", y_values)
+            console.detail("y2_values=", y2_values)
+
+            num_y_ticks = 10
+            ax.get_yaxis().set_major_locator(MaxNLocator(num_y_ticks))
+            #color = self.colors[line_index % len(self.colors)]
+
+            cap_size = 5
+            is_range_plot = bool(y2_values is not None)
+
+            # our default attributes
+            kwargs = {"label": line_title, "color": color, "alpha": alpha, "linewidth": self.line_size}
+            
+            if not is_range_plot:
+                kwargs["capsize"] = cap_size
+
+            # let user override
+            if self.plot_args and not is_range_plot:
+
+                for name, value in self.plot_args.items():
+                    value = utils.make_numeric_if_possible(value)
+                    kwargs[name] = value
+
+            #cmap = self.get_seaborn_color_map("muted")
+            if self.plot_type == "line":
+
+                if is_range_plot:
+
+                    # RANGE plot
+                    ax.fill_between(x_values, y_values, y2_values, **kwargs)
+
+                elif x_values is not None:
+
+                    # X/Y LINE plot
+                    trace = ax.errorbar(x_values, y_values, yerr=err_values, **kwargs)  
+                else:
+
+                    # LINE plot
+                    ax.errorbar(y_values, '-', label=line_title, yerr=err_values, **kwargs)
+
+            else:
+                # for now, we can get lots of milage out of line plot (errorbars, scatter, scatter+line)
+                # so keep things simple and just support 1 type well 
+                errors.syntax_error("unknown plot type={}".format(self.plot_type))
+
+        # this must be called AFTER plotting
+        line_title = self.add_plot_legend_and_title(ax, plot_index, line_index, group_name, col, use_y_label)
 
     def fixup_text(self, text, group_name, col):
         text = text.replace("$job", group_name)
