@@ -4,12 +4,14 @@
 #
 # process_utils.py: helper functions for starting, running processes
 import os
+import time
 import subprocess
 
 from xtlib import console
 from xtlib import pc_utils
 from xtlib import constants
 from xtlib import process_utils
+from xtlib import file_utils
 
 def sync_run(cmd_parts, capture_output=True, shell=False, report_error=False, env_vars=None, 
         capture_as_bytes=False):
@@ -147,14 +149,40 @@ def can_create_console_window():
 
     return cc
 
-def run_cmd_in_new_console(cmd):
+def run_cmd_in_new_console(cmd, noactivate=True):
+    startupinfo=None
+
     if pc_utils.is_windows():
-        # windows
-        os.system("start cmd /K " + cmd)
+        # WINDOWS
+        import win32console
+        import win32gui
+
+        # start the new cmd
+        os.system("start cmd.exe /K " + cmd)
+
+        if noactivate:
+            try:
+                # wait up to 5 secs for fg window to be stolen by new process
+                hwnd = win32console.GetConsoleWindow()
+                if not hwnd:
+                    # sometimes fails?
+                    hwnd = win32gui.GetForegroundWindow()
+
+                for i in range(100):
+                    fg = win32gui.GetForegroundWindow()
+                    if fg != hwnd:
+                        # it has been stolen; steal it back
+                        win32gui.ShowWindow(hwnd, 5)
+                        win32gui.BringWindowToTop(hwnd)
+                        win32gui.SetForegroundWindow(hwnd)
+                        break
+                    time.sleep(.05)
+            except BaseException as ex:
+                console.diag("exception during run_cmd_in_new_console: ex={}".format(ex))
     else:
-        # linux
+        # LINUX
         dest_dir = os.getcwd()
-        fn_log = file_utils.make_tmp_dir() + "/new_console.log"
+        fn_log = file_utils.make_tmp_dir("console_run") + "/new_console.log"
 
         start_async_run_detached(cmd, os.path.expanduser(dest_dir), fn_log, visible=True)
 
