@@ -766,7 +766,9 @@ class Dispatcher():
             # look for abbreviated matches
             matches = [value for value in values if self.match(name, value["name"])]
             if len(matches) > 1:
-                errors.syntax_error("abbreviated name '{}' results in multiple matches: {}".format(name, ", ".join(matches)))
+                match_names = [m["name"] for m in matches]
+                errors.syntax_error("abbreviated name '{}' results in multiple matches: {}" \
+                    .format(name, ", ".join(match_names)))
 
         found = matches[0] if matches else None
         return found
@@ -789,13 +791,6 @@ class Dispatcher():
                 
         return value
 
-    # def process_value(self, value, type):
-    #     if type == "flag":
-    #         if value is not None:
-    #             value = int(value)
-
-    #     return value
-
     def process_root_options(self, scanner, tok):
         options_processed = {}
 
