@@ -283,8 +283,8 @@ class ReportBuilder():
 
         return first, last
 
-    def get_mongo_records(self, mongo, filter_dict, workspace, which, actual_to_user, 
-            col_dict=None, args=None):
+    def get_mongo_records(self, mongo, filter_dict, workspace, which, actual_to_user,
+            col_dict=None, col_names_are_external=True, flatten_records=True, args=None):
 
         started = time.time()
 
@@ -353,10 +353,11 @@ class ReportBuilder():
 
         console.diag("after full records retreival, len(records)={}".format(len(records)))
 
-        if not orig_col_dict:
+        if col_names_are_external:    # not orig_col_dict:
             # pull out standard cols, translating from actual to user-friendly names
             records = [self.translate_record(rec, actual_to_user) for rec in records if rec]
 
+        if flatten_records:
             # pull out requested cols, flattening nested values to their dotted names
             records = self.flatten_records(records, sort_col, args)
 
