@@ -273,7 +273,7 @@ class Run():
             self.store.end_run(self.ws_name, self.run_name, status, exit_code, hparams_dict, metrics_rollup_dict, end_time=None, 
                 restarts=restarts, aggregate_dest=None, dest_name=None, is_aml=True)
 
-            self.store.update_mongo_run_at_end(self.ws_name, self.run_name, status, exit_code, restarts, end_time, log_records, 
+            self.store.update_run_at_end(self.ws_name, self.run_name, status, exit_code, restarts, end_time, log_records, 
                 hparams_dict, metrics_rollup_dict)
 
     def get_store(self):
