@@ -13,6 +13,7 @@ from xtlib import errors
 from xtlib import constants
 from xtlib import file_utils
 from xtlib import job_helper
+from xtlib import store_utils
 
 from xtlib.console import console
 
@@ -118,11 +119,13 @@ def set_run_tags(store, mongo, name_list, tag_list, workspace, fd, clear):
             # update all records
             filter = {}
         else:
-            # update specified run names
+            # convert simple run_name into id required by storage vx
+            run_list = [store_utils.make_id(workspace, run) for run in run_list]
             filter = {"run_name": {"$in": run_list}}
 
             result = mongo.update_runs_from_filter(workspace, filter, fd, clear=clear, upsert=False)
             matched_count = result.matched_count
+
         # for run in run_list:
         #     mongo.update_run_info(workspace, run, fd, clear=clear, upsert=False)  
 
@@ -157,6 +160,19 @@ def list_run_tags(store, mongo, ws_name, name_list, tag_list):
     else:
         console.print("no matching run found")
 
+def remove_run_stats(dd: dict):
+    run_stat_props = ["status", "last_time", "exit_code", "restarts", "end_time", "end_id", 
+        "metric_names", "start_time", "duration", "run_duration", "queue_duration"]
+    run_stats = {}
+
+    for prop in run_stat_props:
+        if prop in dd:
+            value = dd[prop]
+            run_stats[prop] = value
+            del dd[prop]
+
+    return run_stats
+
 def get_run_property_dicts():
     # user-friendly property names for jobs
     user_to_actual = {"box": "box_name", "created": "create_time", "child": "is_child", "cluster": "cluster",
@@ -237,14 +253,17 @@ def build_filter_part(fd, args, arg_name, store_name):
         else:
             fd[store_name] = value
 
-def build_run_filter_dict(run_list, user_to_actual, builder, args):
+def build_run_filter_dict(ws_name, run_list, user_to_actual, builder, args):
     fd = {}
     option_filters = ["job", "experiment", "target", "service_type", "box", "status", "parent", "child", "outer", "username"]  
 
     explict_options = qfe.get_explicit_options()
 
     if run_list:
-        # filter by specified job names
+        # filter by specified run names
+        # convert simple run_name into id required by storage vx
+        run_list = [store_utils.make_id(ws_name, run) for run in run_list]
+
         fd["_id"] = {"$in": run_list}
 
     # filter by specified options
@@ -293,7 +312,8 @@ def extract_dotted_cols(records, prefix):
 
     return list(nd.keys())
 
-def get_filtered_sorted_limit_runs(store, config, show_gathering, col_dict=None, args=None, preserve_order=False):
+def get_filtered_sorted_limit_runs(store, config, show_gathering, col_dict=None, preserve_order=False, 
+        col_names_are_external=True, flatten_records=True, args=None):
     # JIT import (workaround cyclic imports)
     from xtlib.report_builder import ReportBuilder   
 
@@ -305,6 +325,11 @@ def get_filtered_sorted_limit_runs(store, config, show_gathering, col_dict=None,
     pool = utils.safe_value(args, "target")
     available = utils.safe_value(args, "available")
     workspace = utils.safe_value(args, "workspace")
+
+    # if not col_dict:
+    #     col_list = utils.safe_value(args, "columns")
+    #     if col_list:
+    #         col_dict = {col: 1 for col in col_list}
     
     if workspace:
         store.ensure_workspace_exists(workspace, flag_as_error=False)
@@ -323,14 +348,22 @@ def get_filtered_sorted_limit_runs(store, config, show_gathering, col_dict=None,
         errors.general_error("no matching runs found")
 
     # build a filter dict for all specified filters
-    filter_dict = build_run_filter_dict(pure_run_list, user_to_actual, builder, args)
+    filter_dict = build_run_filter_dict(workspace, pure_run_list, user_to_actual=user_to_actual, 
+        builder=builder, args=args)
 
     # if show_gathering:
     #     console.print("gathering run data...", flush=True)
 
     # get the mongo records for the matching RUNS
-    records, using_default_last, last = builder.get_mongo_records(mongo, filter_dict, workspace, "runs", actual_to_user, 
-        col_dict=col_dict, args=args)
+    records, using_default_last, last = builder.get_mongo_records(mongo, filter_dict, workspace, which="runs", 
+        actual_to_user=actual_to_user, col_dict=col_dict, col_names_are_external=col_names_are_external, 
+        flatten_records=flatten_records, args=args)
+
+    # remove key info from _id in records
+    store_utils.simplify_records_id(records)
+
+    # remove key from pure_run_list
+    pure_run_list = [pr.split("/")[-1] for pr in pure_run_list]
 
     if preserve_order:
         records = order_runs_by_user_list(records, pure_run_list)
@@ -343,7 +376,7 @@ def order_runs_by_user_list(runs, user_list):
     new_records = list(user_list)
 
     for run in runs:
-        run_name = run["_id"]
+        run_name = run["_id"] if "_id" in run else run["run"]
         index = new_records.index(run_name)
         if index > -1:
             new_records[index] = run
@@ -355,7 +388,8 @@ def order_runs_by_user_list(runs, user_list):
 def list_runs(store, config, args):
 
     records, using_default_last, user_to_actual, available, builder, last, std_cols_desc = \
-        get_filtered_sorted_limit_runs(store, config, True, args=args)
+        get_filtered_sorted_limit_runs(store, config, show_gathering=True, 
+            col_names_are_external=True, flatten_records=True, args=args)
 
     if available:
         std_cols = list(user_to_actual.keys())
@@ -372,6 +406,10 @@ def list_runs(store, config, args):
         #avail_list = list(user_to_actual.keys())
         lines, row_count, was_exported = builder.build_report(records, report_type="run-reports", args=args)
 
+        store_name = config.get("store")
+        workspace = args["workspace"]
+        console.print("runs on {}/{}:".format(store_name, workspace))
+
         if was_exported:
             console.print("")
 
