@@ -16,6 +16,8 @@ from xtlib import utils
 from xtlib import errors
 from xtlib import console
 from xtlib import constants
+from xtlib import job_helper
+from xtlib import run_helper
 
 DEFAULT_DB = "__default__"
 MONGO_INFO = "__mongo_info__"
@@ -182,7 +184,7 @@ class MongoDB2():
             self.mongo_with_retries("delete_from_collection", lambda: dbx[collection_name].delete_many( {"ws_name": ws_name} ))
 
     def limited_bulk_delete(self, dbx, collection_name, ids):
-        max_deletes = 25
+        max_deletes = 10    # 25 gives "request rate is too large" errors 
         index = 0
 
         while index < len(ids):
@@ -578,6 +580,103 @@ class MongoDB2():
         next_id = record[path]
         return next_id
 
+    def create_mongo_run(self, orig_dd):
+        '''
+        Create or update run information in any/all of the 5 run collections.
+        '''
+        ws_name = orig_dd["ws_name"]
+        run_name = orig_dd["run_name"]
+
+        self.update_run_info(ws_name, run_name, orig_dd, update_primary=True)
+
+    def update_run_info(self, ws_name, run_name, orig_dd, hparams=None, metrics=None, update_primary=False):
+        '''
+        Args:
+            - ws_name: name of the associated workspace
+            - run_name: name of the run being updated
+            - orig_dd: a dictionary of name/value pairs.  Can include nested: hparams, metrics, log_records
+            - hparams dict (optional, usually passed in orig_dd)
+            - metrics dict (optional, usually passed in orig_dd)
+            - update_primary: specifies if the run_info collection be updated
+
+        Processing:
+            This is the CORE function for updating run related information.  The following 
+            collections may be updated: run_info, run_stats, metrics, hparams, log_records
+
+            In order for the run_info collection to be updated, update_primary must = True.
+        '''
+        dbx = self.get_db(ws_name)
+        dd = dict(orig_dd)      # make copy so we can modify
+
+        # normalize nested info, if present
+        if not hparams:
+            hparams = {}
+            utils.safe_move(hparams, dd, "hparams", flatten=True)
+
+        if not metrics:
+            metrics = {}
+            utils.safe_move(metrics, dd, "metrics", flatten=True)
+
+        log_records = {}
+        utils.safe_move(log_records, dd, "log_records", flatten=False)
+        if log_records:
+            log_records = log_records["log_records"]     # list or dict
+
+        run_stats = run_helper.remove_run_stats(dd)
+
+        #print("dd=", dd)
+        self.disallow_embedded_props(dd)
+        
+        run_stats["last_time"] = utils.get_time()
+        
+        _id = self.make_key(ws_name, run_name)
+
+        # # correct for v1 name of workspace
+        # if not "ws_name" in dd:
+        #     dd["ws_name"] = ws_name
+        #     if "ws" in dd:
+        #         del dd["ws"]
+
+        # update RUN_INFO
+        if update_primary:
+            dd["_id"] = _id
+            dd["ws_name"] = ws_name
+            update_doc = { "$set": dd}
+            self.mongo_with_retries("update_run_info", \
+                lambda: dbx["run_info"].update_one( {"_id": _id}, update_doc, upsert=True))
+
+        # update RUN_STATS
+        if self.update_run_stats and run_stats:
+            run_stats["_id"] = _id
+            run_stats["ws_name"] = ws_name
+            update_doc = { "$set": run_stats}
+            self.mongo_with_retries("update_run_info", \
+                lambda: dbx["run_stats"].update_one( {"_id": _id}, update_doc, upsert=True))
+
+        # update HPARAMS
+        if hparams:
+            hparams["_id"] = _id
+            hparams["ws_name"] = ws_name
+            update_doc = { "$set": hparams}
+            self.mongo_with_retries("update_run_info", \
+                lambda: dbx["hparams"].update_one( {"_id": _id}, update_doc, upsert=True))
+
+        # update METRICS
+        if metrics:
+            metrics["_id"] = _id
+            metrics["ws_name"] = ws_name
+            update_doc = { "$set": metrics}
+            self.mongo_with_retries("update_run_info", \
+                lambda: dbx["metrics"].update_one( {"_id": _id}, update_doc, upsert=True))
+
+        # update LOG_RECORDS
+        if log_records:
+            if isinstance(log_records, list):
+                # list of log records (likely called from import)
+                self.add_log_record_bulk_limited(ws_name, run_name, log_records)
+            else:
+                self.add_log_record(ws_name, run_name, log_records)
+
     def process_run_event(self, ws_name, run_name, event, dd, record_dict):
         run_stats = {}
         completed = False
@@ -617,17 +716,70 @@ class MongoDB2():
             self.add_id(run_stats, ws_name, run_name)
             self.update_collection("run_stats", ws_name, run_stats)
 
-        # add to LOG_RECORDS
-        record = dict(record_dict)    # make local copy that we can update
+        self.add_log_record(ws_name, run_name, record_dict)
+        return completed
+
+    def add_log_record(self, ws_name, run_name, orig_dd):
+        '''
+        add single log record dict (dd) to LOG_RECORDS collection
+        '''
+        dd = dict(orig_dd)    # make local copy that we can update
         
-        # assign a GUID to each record's id
-        record["_id"] = str(uuid.uuid4())
+        # assign a GUID to each log record's id
+        dd["_id"] = str(uuid.uuid4())
+        dd["ws_name"] = ws_name
 
         key = self.make_key(ws_name, run_name)
-        record["key"] = key
-        self.update_collection("log_records", ws_name, record, is_flat=False)
+        dd["key"] = key
 
-        return completed
+        self.update_collection("log_records", ws_name, dd, is_flat=False)
+
+    def add_log_record_bulk_limited(self, ws_name, run_name, log_records):
+        '''
+        add multiple log record dicts to LOG_RECORDS collection
+        '''
+        dbx = self.get_db(ws_name)
+        key = self.make_key(ws_name, run_name)
+
+        max_inserts = 10    # 25 gets request rate errors
+        index = 0
+
+        while index < len(log_records):
+            log_batch = log_records[index : index+max_inserts]
+
+            for dd in log_batch:
+                # assign a GUID to each log record's id
+                dd["_id"] = str(uuid.uuid4())
+                dd["ws_name"] = ws_name
+
+                if not "key" in dd:
+                    dd["key"] = key
+
+            self.mongo_with_retries("add_log_record_bulk_limited", lambda: dbx["log_records"].insert_many(log_batch) )
+
+            index += len(log_batch)
+
+    def update_runs_from_filter(self, ws_name, filter, dd, clear=False, upsert=True):
+        '''
+        Update 1 or more run_stats documents from a single set of dd properties.
+        Mostly used to update tags on runs.
+        '''
+        dbx = self.get_db(ws_name)
+
+        if clear:
+            update_doc = { "$unset": dd}
+        else:
+            update_doc = { "$set": dd}
+
+        # ensure we filter by ws_name to target correct runs
+        if not "ws_name" in filter:
+            filter["ws_name"] = ws_name
+
+        # update, create prop if needed
+        result = self.mongo_with_retries("update_runs_from_filter", \
+            lambda: dbx["run_stats"].update_many( filter, update_doc, upsert=upsert) )
+
+        return result
 
     def process_job_events(self, ws_name, job_id, event_records):
         completed = False
@@ -848,7 +1000,7 @@ class MongoDB2():
 
         return job_completed
 
-    def update_mongo_run_at_end(self, ws_name, run_name, status, exit_code, restarts, end_time, log_records, hparams, metrics):
+    def update_run_at_end(self, ws_name, run_name, status, exit_code, restarts, end_time, log_records, hparams, metrics):
         # update run document on Mongo DB
         dbx = self.get_db(ws_name)
 
@@ -865,41 +1017,6 @@ class MongoDB2():
 
             self.update_run_info(ws_name, run_name, updates, hparams, metrics)
 
-    def update_run_info(self, ws_name, run_name, dd, hparams=None, metrics=None):
-
-        if self.update_run_stats:
-            dbx = self.get_db(ws_name)
-    
-            # normalize nested info, if present
-            if not hparams:
-                hparams = {}
-                utils.safe_move(hparams, dd, "hparams", flatten=True)
-
-            if not metrics:
-                metrics = {}
-                utils.safe_move(metrics, dd, "metrics", flatten=True)
-
-            #print("dd=", dd)
-            self.disallow_embedded_props(dd)
-            
-            update_dd = dict(dd)
-            update_dd["last_time"] = utils.get_time()
-            _id = ws_name + "/" + run_name
-
-            # update RUN_STATS
-            update_doc = { "$set": update_dd}
-            self.mongo_with_retries("update_run_info", lambda: dbx["run_stats"].update_one( {"_id": _id}, update_doc) )
-
-            if hparams:
-                # update HPARAMS
-                update_doc = { "$set": hparams}
-                self.mongo_with_retries("update_run_info", lambda: dbx["hparams"].update_one( {"_id": _id}, update_doc) )
-
-            if metrics:
-                # update METRICS
-                update_doc = { "$set": metrics}
-                self.mongo_with_retries("update_run_info", lambda: dbx["metrics"].update_one( {"_id": _id}, update_doc) )
-
     def print_call_stats(self):
         total_count = 0
         total_time = 0
@@ -1196,7 +1313,7 @@ class MongoDB2():
 
         return records
 
-    def calc_needed_run_collections(self, fields_dict):
+    def calc_needed_run_collections(self, fields_dict, include_log_records=False):
         '''
         Processing:
             Collect names of related run collections specified by fields_dict
@@ -1209,7 +1326,7 @@ class MongoDB2():
         needed["run_stats"] = default
         needed["metrics"] = default
         needed["hparams"] = default
-        needed["log_records"] = 0
+        needed["log_records"] = include_log_records
 
         if fields_dict:
             orig_fd = dict(fields_dict)
@@ -1265,10 +1382,11 @@ class MongoDB2():
         
         return records
 
-    def get_info_for_runs(self, ws_name, filter_dict, fields_dict=None):
+    def get_info_for_runs(self, ws_name, filter_dict, fields_dict=None, include_log_records=False):
 
         self.round_trip_count = 0
-        needed_collections, fields_dict = self.calc_needed_run_collections(fields_dict)
+        needed_collections, fields_dict = self.calc_needed_run_collections(fields_dict, \
+            include_log_records=include_log_records)
 
         records = self.get_info_for_collection(ws_name, "run_info", filter_dict, fields_dict)
 
