@@ -73,18 +73,30 @@ def Store(storage_creds=None, config=None, max_retries=10, run_cache_dir=None, f
     provider = class_ctr(storage_creds)
 
     # does the version 1 system info container exist?
-    use_v1 = provider.does_container_exist(constants.INFO_CONTAINER_V1)
+    if provider.does_container_exist(constants.INFO_CONTAINER_V2):
+        use_v1 = False
+    else:
+        use_v1 = provider.does_container_exist(constants.INFO_CONTAINER_V1)
 
     if use_v1:
+        #----- V1 store ----
         # JIT import to minimize impact of V1
         from xtlib.storage_v1.store_v1 import StoreV1
+        assert not provider.does_container_exist(constants.INFO_CONTAINER_V2)
 
         store = StoreV1(storage_creds, config, max_retries, run_cache_dir, feedback_enabled,  mongo_conn_str, 
             provider_code_path, validate_creds)
+
+        assert not provider.does_container_exist(constants.INFO_CONTAINER_V2)
     else:
+        #----- V2 store ----
+        assert not provider.does_container_exist(constants.INFO_CONTAINER_V1)
+
         store = StoreV2(storage_creds, config, max_retries, run_cache_dir, feedback_enabled,  mongo_conn_str, 
             provider_code_path, validate_creds)
 
+        assert not provider.does_container_exist(constants.INFO_CONTAINER_V1)
+
     return store
 
 # main class that implements the XT STORE API
@@ -376,7 +388,14 @@ class StoreV2():
 
     def get_run_names(self, ws_name):
         ''' get a flat list of all run_names in the workspace. '''
-        return self.helper.get_run_names(ws_name)
+
+        # use mongo for faster results
+        #return self.helper.get_run_names(ws_name)
+
+        records = self.mongo.get_info_for_runs(ws_name, {"ws_name": ws_name}, {"run_name": 1})
+        run_names = [r["run_name"] for r in records]
+
+        return run_names
 
     # def append_experiment_run_name(self, ws_name, exper_name, run_name):
     #     self.helper.append_experiment_run_name( ws_name, exper_name, run_name)
@@ -723,7 +742,7 @@ class StoreV2():
             end_time=end_time, aggregate_dest=aggregate_dest, dest_name=dest_name, is_aml=is_aml)
 
         if self.mongo:
-            self.mongo.update_mongo_run_at_end(ws_name, run_name, status, exit_code, restarts, end_time, log_records, hparams, metrics)
+            self.mongo.update_run_at_end(ws_name, run_name, status, exit_code, restarts, end_time, log_records, hparams, metrics)
 
     def _roll_up_hparams(self, log_records):
         hparams_dict = {}
@@ -879,11 +898,11 @@ class StoreV2():
     def copy_run_files_to_run(self, ws_name, from_run, run_wildcard, to_run, to_path):
         return self.helper.copy_run_files_to_run(ws_name, from_run, run_wildcard, to_run, to_path)
 
-    def update_mongo_run_at_end(self, ws_name, run_name, status, exit_code, restarts, end_time, log_records, hparams, metrics):
+    def update_run_at_end(self, ws_name, run_name, status, exit_code, restarts, end_time, log_records, hparams, metrics):
         result = None
 
         if self.mongo:
-            result = self.mongo.update_mongo_run_at_end(ws_name, run_name, status, exit_code, restarts, end_time, log_records, hparams, metrics)
+            result = self.mongo.update_run_at_end(ws_name, run_name, status, exit_code, restarts, end_time, log_records, hparams, metrics)
 
         return result
 
@@ -929,12 +948,12 @@ class StoreV2():
         rf = self.run_files(ws_name, run_name, use_blobs=True)
         return rf.upload_files(run_folder, source_wildcard, exclude_dirs_and_files=exclude_dirs_and_files)
 
-    def download_file_from_run(self, ws_name, run_name, run_fn, dest_fn):
+    def download_file_from_run(self, ws_name, run_name, run_fn, dest_fn, job_id=None):
         '''download the run file 'run_fn' to the local file 'dest_fn'.
         '''
         dest_fn = os.path.abspath(dest_fn)      # ensure it has a directory specified
         #return self.helper.download_file_from_run(ws_name, run_name, run_fn, dest_fn)
-        rf = self.run_files(ws_name, run_name, use_blobs=True)
+        rf = self.run_files(ws_name, run_name, use_blobs=True, job_id=job_id)
         return rf.download_file(run_fn, dest_fn)
 
     def download_files_from_run(self, ws_name, run_name, run_wildcard, dest_folder):
@@ -1123,8 +1142,8 @@ class StoreV2():
     def workspace_files(self, ws_name, use_blobs=False):
         return self.helper.workspace_files(ws_name, use_blobs)
 
-    def run_files(self, ws_name, run_name, use_blobs=False):
-        return self.helper.run_files(ws_name, run_name, use_blobs)
+    def run_files(self, ws_name, run_name, use_blobs=False, job_id=None):
+        return self.helper.run_files(ws_name, run_name, use_blobs, job_id=job_id)
 
     def experiment_files(self, ws_name, exper_name, use_blobs=False):
         return self.helper.experiment_files(ws_name, exper_name, use_blobs)
