@@ -122,17 +122,17 @@ class StoreBlobObjs():
                 console.print("  {} jobs imported".format(count))
 
     def _get_storage_info(self):
-        text = self._read_blob(constants.INFO_CONTAINER, constants.STORAGE_INFO_FILE)
+        text = self._read_blob(constants.INFO_CONTAINER_V2, constants.STORAGE_INFO_FILE)
         info = json.loads(text)
         return info
 
     def _set_storage_info(self, info):
         # write back to blob
         text = json.dumps(info)
-        self._create_blob(constants.INFO_CONTAINER, constants.STORAGE_INFO_FILE, text)
+        self._create_blob(constants.INFO_CONTAINER_V2, constants.STORAGE_INFO_FILE, text)
 
     def _create_info_container_if_needed(self):
-        info_container = constants.INFO_CONTAINER
+        info_container = constants.INFO_CONTAINER_V2
 
         container_exists = self.provider.does_container_exist(info_container)
         if not container_exists or not self.provider.does_blob_exist(info_container, constants.STORAGE_INFO_FILE):
@@ -886,9 +886,11 @@ class StoreBlobObjs():
 
     # ---- FILES OBJECTS helper functions ----
 
-    def run_files(self, ws_name, run_name, use_blobs=False):
+    def run_files(self, ws_name, run_name, use_blobs=False, job_id=None):
         if use_blobs:
-            return RunBlobs(self, ws_name, run_name)
+            if not job_id:
+                job_id = "job" + str(run_helper.get_parent_run_number(run_name))
+            return RunBlobs(self, ws_name, job_id, run_name)
         else:
             return store_azure_file.RunFiles(self, ws_name, run_name)
 
@@ -1105,8 +1107,11 @@ class BlobsObject():
         return self.store._download_files(container, path, wc_target, dest_folder)
 
     def get_filenames(self, wildcard="*", full_paths=False):
-        if not "*" in wildcard:
+        if not wildcard:
+            wildcard = "*"
+        elif not "*" in wildcard:
             wildcard += "/*"
+
         container, path, wc_target = self._get_container_path_target(wildcard)
         names = self.store._list_wild_blobs(container, path, wc_target, include_folder_names=True)
 
@@ -1177,12 +1182,11 @@ class WorkspaceBlobs(BlobsObject):
         self.base_path = constants.WORKSPACE_DIR
 
 class RunBlobs(BlobsObject):
-    def __init__(self, store, ws_name, run_name):
+    def __init__(self, store, ws_name, job_id, run_name):
         self.store = store
         self.container = ws_name
 
-        parent_num = run_helper.get_parent_run_number(run_name)
-        self.base_path = "jobs/job{}/runs/{}".format(parent_num, run_name)
+        self.base_path = "jobs/{}/runs/{}".format(job_id, run_name)
 
 class ExperimentBlobs(BlobsObject):
     def __init__(self, store, ws_name, exper_name):
