@@ -307,12 +307,12 @@ class MongoDB():
         cmd = lambda: self.mongo_db[ws_name].insert_one(run_doc)
         self.mongo_with_retries("create_mongo_run", cmd, ignore_error=True)
 
-    def add_run_event(self, ws_name, run_name, log_record):
+    def process_run_event(self, ws_name, run_name, log_record):
 
         if self.add_log_records:
             # first, add log record to ws/run document
             update_doc = { "$push": {"log_records": log_record} }
-            self.mongo_with_retries("add_run_event", lambda: self.mongo_db[ws_name].update_one( {"_id": run_name}, update_doc, upsert=True) )
+            self.mongo_with_retries("process_run_event", lambda: self.mongo_db[ws_name].update_one( {"_id": run_name}, update_doc, upsert=True) )
 
         if self.update_run_stats:
             event_name = log_record["event"]
@@ -322,28 +322,28 @@ class MongoDB():
             if event_name == "hparams":
                 # create a "hparams" dict property for the run record
                 self.flatten_dict_update(updates, "hparams", data_dict)
-                self.update_mongo_run_from_dict(ws_name, run_name, updates)
+                self.update_run_info(ws_name, run_name, updates)
 
             elif event_name == "metrics":
                 # create a "metrics" dict property for the run record (most recent metrics)
                 self.flatten_dict_update(updates, "metrics", data_dict)
-                self.update_mongo_run_from_dict(ws_name, run_name, updates)
+                self.update_run_info(ws_name, run_name, updates)
 
             if event_name == "started":
                 updates = { "status": "running" }
                 #console.print("updating run STATUS=", updates)
-                self.update_mongo_run_from_dict(ws_name, run_name, updates)
+                self.update_run_info(ws_name, run_name, updates)
 
             elif event_name == "status-change":
                 updates = { "status": data_dict["status"] }
                 #console.print("updating run STATUS=", updates)
-                self.update_mongo_run_from_dict(ws_name, run_name, updates)
+                self.update_run_info(ws_name, run_name, updates)
 
     def flatten_dict_update(self, updates, dd_name, dd):
         for key, value in dd.items():
             updates[dd_name + "." + key] = value
 
-    def update_mongo_run_at_end(self, ws_name, run_name, status, exit_code, restarts, end_time, log_records, hparams, metrics):
+    def update_run_at_end(self, ws_name, run_name, status, exit_code, restarts, end_time, log_records, hparams, metrics):
         # update run document on Mongo DB
 
         if self.update_run_stats:
@@ -369,28 +369,44 @@ class MongoDB():
             # no longer need this step here (log records are now appended as they are logged)
             #updates["log_records"] = log_records
 
-            self.update_mongo_run_from_dict(ws_name, run_name, updates)
+            self.update_run_info(ws_name, run_name, updates)
 
-    def update_mongo_run_from_dict(self, ws_name, run_name, dd):
-        #console.print("update_mongo_run_from_dict: ws_name={}, run_name={}, dd={}".format(ws_name, run_name, dd))
+    def update_run_info(self, ws_name, run_id, orig_dd, clear=False, upsert=True, update_primary=False):
+
+        dd = dict(orig_dd)
 
         if self.update_run_stats:
-            update_dd = copy.deepcopy(dd)
-            update_dd["last_time"] = utils.get_time()
+            if clear:
+                update_doc = { "$unset": dd}
+            else:
+                dd["last_time"] = utils.get_time()
+                update_doc = { "$set": dd}
 
-            update_doc = { "$set": update_dd}
+            # update, create prop if needed
+            self.mongo_with_retries("update_run_info", \
+                lambda: self.mongo_db[ws_name].update_one( {"_id": run_id}, update_doc, upsert=upsert) )
 
-            #console.print("update_mongo_run_from_dict: ws_name={}, run_name={}, update_doc={}".format(ws_name, run_name, update_doc))
 
-            # do a REPLACE DOC update operation
-            self.mongo_with_retries("update_mongo_run_from_dict", lambda: self.mongo_db[ws_name].update_one( {"_id": run_name}, update_doc) )
+    # def update_run_info(self, ws_name, run_name, dd):
+    #     #console.print("update_run_info: ws_name={}, run_name={}, dd={}".format(ws_name, run_name, dd))
+
+    #     if self.update_run_stats:
+    #         update_dd = copy.deepcopy(dd)
+    #         update_dd["last_time"] = utils.get_time()
+
+    #         update_doc = { "$set": update_dd}
+
+    #         #console.print("update_run_info: ws_name={}, run_name={}, update_doc={}".format(ws_name, run_name, update_doc))
+
+    #         # do a REPLACE DOC update operation
+    #         self.mongo_with_retries("update_run_info", lambda: self.mongo_db[ws_name].update_one( {"_id": run_name}, update_doc) )
 
     def does_run_exist(self, ws, run_name):
         records = self.get_info_for_runs(ws, {"_id": run_name}, {"_id": 1})
         exists = len(records) == 1
         return exists
 
-    def get_info_for_runs(self, ws_name, filter_dict, fields_dict=None):
+    def get_info_for_runs(self, ws_name, filter_dict, fields_dict=None, include_log_records=False):
 
         self.v2_to_v1_run_cols(filter_dict)
         self.v2_to_v1_run_cols(fields_dict)
@@ -553,17 +569,6 @@ class MongoDB():
 
         return records
 
-    def update_run_info(self, ws_name, run_id, dd, clear=False, upsert=True):
-
-        if self.update_run_stats:
-            if clear:
-                update_doc = { "$unset": dd}
-            else:
-                update_doc = { "$set": dd}
-
-            # update, create prop if needed
-            self.mongo_with_retries("update_run_info", lambda: self.mongo_db[ws_name].update_one( {"_id": run_id}, update_doc, upsert=upsert) )
-
     def update_runs_from_filter(self, ws_name, filter, dd, clear=False, upsert=True):
 
         if self.update_run_stats:
