@@ -23,6 +23,7 @@ from xtlib import utils
 from xtlib import errors
 from xtlib import constants
 from xtlib import file_utils
+from xtlib import store_utils
 
 from xtlib.console import console
 
@@ -80,11 +81,11 @@ class StoreBlobObjs():
                 connected_mongo, paired_mongo))
 
         if not paired_storage:
-            mongo_info = {"paired_storage": storage_name, "storage_version": constants.STORAGE_VERSION}
+            mongo_info = {"paired_storage": storage_name, "storage_version": constants.STORAGE_FORMAT_V1}
             mongo.set_mongo_info(mongo_info)
 
         if not paired_mongo:
-            storage_info = {"paired_mongo": connected_mongo, "storage_version": constants.STORAGE_VERSION}
+            storage_info = {"paired_mongo": connected_mongo, "storage_version": constants.STORAGE_FORMAT_V1}
             self._set_storage_info(storage_info)
 
         # only check once, (takes .5 secs if already imported)
@@ -135,7 +136,7 @@ class StoreBlobObjs():
                 self.provider.create_container(info_container)
 
             # create storage info file
-            info = {"version": constants.STORAGE_VERSION, "paired_mongo": None}
+            info = {"version": constants.STORAGE_FORMAT_V1, "paired_mongo": None}
             text = json.dumps(info)
             self._create_blob(info_container, constants.STORAGE_INFO_FILE, text)
 
@@ -672,10 +673,10 @@ class StoreBlobObjs():
 
     def get_workspace_names(self):
 
-        # legacy - mongo.get_workspace_names is now preferred
+        log_path = constants.WORKSPACE_DIR + "/" + constants.WORKSPACE_LOG
         containers = self.provider.list_containers()
-        names = [name for name in containers if self.workspace_files(name, use_blobs=True).does_file_exist(WORKSPACE_NEXT)]
-       
+        
+        names = [name for name in containers if self.provider.does_blob_exist(name, log_path)]
         return names
 
     # ---- EXPERIMENTS ----
@@ -1110,8 +1111,11 @@ class BlobsObject():
         return self.store._download_files(container, path, wc_target, dest_folder)
 
     def get_filenames(self, wildcard="*", full_paths=False):
-        if not "*" in wildcard:
+        if not wildcard:
+            wildcard = "*"
+        elif not "*" in wildcard:
             wildcard += "/*"
+            
         container, path, wc_target = self._get_container_path_target(wildcard)
         names = self.store._list_wild_blobs(container, path, wc_target, include_folder_names=True)
 
