@@ -86,6 +86,7 @@ class StoreV1():
         store_utils.is_share_name = is_share_name
         store_utils.get_run_path = get_run_path
         store_utils.get_jobs_container = get_jobs_container
+        store_utils.make_id = make_id
 
         self.feedback_enabled = feedback_enabled
 
@@ -731,7 +732,7 @@ class StoreV1():
         self.end_run(ws_name, run_name, status, exit_code, hparams, metrics, restarts=restarts, 
             end_time=end_time, aggregate_dest=aggregate_dest, dest_name=dest_name, is_aml=is_aml)
 
-        self.mongo.update_mongo_run_at_end(ws_name, run_name, status, exit_code, restarts, end_time, log_records, hparams, metrics)
+        self.mongo.update_run_at_end(ws_name, run_name, status, exit_code, restarts, end_time, log_records, hparams, metrics)
 
     def _roll_up_hparams(self, log_records):
         hparams_dict = {}
@@ -826,7 +827,7 @@ class StoreV1():
             self.append_run_file(ws_name, run_name, RUN_LOG, rd_text + "\n")
 
         # log all backend types to mongo
-        self.mongo.add_run_event(ws_name, run_name, record_dict)
+        self.mongo.process_run_event(ws_name, run_name, record_dict)
 
     def get_job_names(self, filter_dict=None, fields_dict=None):
         return self.mongo.get_job_names(filter_dict, fields_dict)
@@ -884,8 +885,8 @@ class StoreV1():
     def copy_run_files_to_run(self, ws_name, from_run, run_wildcard, to_run, to_path):
         return self.helper.copy_run_files_to_run(ws_name, from_run, run_wildcard, to_run, to_path)
 
-    def update_mongo_run_at_end(self, ws_name, run_name, status, exit_code, restarts, end_time, log_records, hparams, metrics):
-        return self.mongo.update_mongo_run_at_end(ws_name, run_name, status, exit_code, restarts, end_time, log_records, hparams, metrics)
+    def update_run_at_end(self, ws_name, run_name, status, exit_code, restarts, end_time, log_records, hparams, metrics):
+        return self.mongo.update_run_at_end(ws_name, run_name, status, exit_code, restarts, end_time, log_records, hparams, metrics)
 
     #---- LOW LEVEL ----
             
@@ -929,7 +930,7 @@ class StoreV1():
         rf = self.run_files(ws_name, run_name, use_blobs=True)
         return rf.upload_files(run_folder, source_wildcard, exclude_dirs_and_files=exclude_dirs_and_files)
 
-    def download_file_from_run(self, ws_name, run_name, run_fn, dest_fn):
+    def download_file_from_run(self, ws_name, run_name, run_fn, dest_fn, job_id=None):
         '''download the run file 'run_fn' to the local file 'dest_fn'.
         '''
         dest_fn = os.path.abspath(dest_fn)      # ensure it has a directory specified
@@ -1131,7 +1132,7 @@ class StoreV1():
     def workspace_files(self, ws_name, use_blobs=False):
         return self.helper.workspace_files(ws_name, use_blobs)
 
-    def run_files(self, ws_name, run_name, use_blobs=False):
+    def run_files(self, ws_name, run_name, use_blobs=False, job_id=None):
         return self.helper.run_files(ws_name, run_name, use_blobs)
 
     def experiment_files(self, ws_name, exper_name, use_blobs=False):
@@ -1157,3 +1158,10 @@ def get_run_path(job_id, run_name):
 
 def get_jobs_container(ws_name):
     return constants.INFO_CONTAINER_V1    
+
+def make_id(ws_name, obj_name):
+    if "/" in obj_name:
+        id = obj_name.split("/", 1)[1]
+    else:
+        id = obj_name
+    return id
