@@ -20,12 +20,13 @@ from xtlib.cache_client import CacheClient
 
 class XTVault():
 
-    def __init__(self, vault_url, ss_name):
+    def __init__(self, vault_url, store_name, secret_name):
         self.vault_url = vault_url
-        self.ss_name = ss_name
+        self.store_name = store_name
         self.client = None
         self.authentication = None
         self.keys = None
+        self.secret_name = secret_name
 
     def init_creds(self, authentication):
         cache_client = CacheClient()
@@ -39,19 +40,19 @@ class XTVault():
             loaded = self._load_node_creds()
         if not loaded and self.vault_url:
             # normal XT client
-            creds = cache_client.get_creds(self.ss_name)
+            creds = cache_client.get_creds(self.store_name)
             if creds:
                 self.apply_creds(creds)
             else:
                 creds = self._get_creds_from_login(authentication, reason="cache not set")
-                cache_client.store_creds(self.ss_name, creds)
+                cache_client.store_creds(self.store_name, creds)
 
     def _load_grok_creds(self):
         fn_keys = "keys.bin"
         loaded = False
 
         if not os.path.exists(fn_keys):
-            fn_keys = os.path.expanduser("~/.xt/service_sets/{}/keys.bin".format(self.ss_name))
+            fn_keys = os.path.expanduser("~/.xt/stores/{}/keys.bin".format(self.store_name))
 
         if os.path.exists(fn_keys):
             # GROK server creds
@@ -121,7 +122,7 @@ class XTVault():
 
         # get keys from keyvault
         self.client = SecretClient(self.vault_url, credential=credential)
-        key_text = self.get_secret_live("xt-keys")
+        key_text = self.get_secret_live(self.secret_name)
         console.print("authenticated successfully", flush=True)
 
         #xt_client_cert = self.get_secret_live("xt-clientcert")
